import Vue from 'vue'
import Cookies from 'js-cookie'
import 'normalize.css/normalize.css' // a modern alternative to CSS resets
import Element from 'element-ui'
import './assets/styles/element-variables.scss'

import '@/assets/styles/index.scss' // global css
import '@/assets/styles/common.scss' // common css
import App from './App'
import store from './store'
import router from './router'
import permission from './directive/permission'

import VueClipboard from 'vue-clipboard2'
//图片上传组件
import ImageUpload from "@/components/ImageUpload"

import './assets/icons' // icon
import './permission' // permission control
import { getDicts } from "@/api/system/dict/data";
import { getConfigKey } from "@/api/company/companyConfig";
import { callMobile } from "@/api/company/companyVoiceApi"
import { getAge,formatDate,parsePost,parseArr,formatMoney, resetForm, addDateRange, selectDictLabel, selectDictLabels, download, handleTree,parseTime,dateFormat,friendlyDate,formatTime } from "@/utils/common";
import { callNumber,callOff } from "@/utils/call";
import elementDirective from './directive/select'

import Pagination from "@/components/Pagination";
//自定义表格工具扩展
import RightToolbar from "@/components/RightToolbar"
import FormMaking from 'form-making'
import 'form-making/dist/FormMaking.css'
// 字典标签组件
import DictTag from '@/components/DictTag'

Vue.use(VueClipboard)

Vue.use(FormMaking)
// 全局方法挂载
Vue.component('ImageUpload',ImageUpload)

import audio from 'vue-mobile-audio'
Vue.use(audio)



Vue.prototype.callNumber = callNumber
Vue.prototype.callOff = callOff
Vue.prototype.callMobile = callMobile

//import LemonIMUI from 'lemon-imui';
import LemonIMUI from '@/components/LemonUI';
Vue.use(LemonIMUI);

// import qwIm  from "@/utils/webSocket";
// Vue.prototype.qwIm = qwIm

// Vue.prototype.callOffMobile = callOffMobile
// Vue.prototype.getSipAccount = getSipAccount


Vue.prototype.getDicts = getDicts
Vue.prototype.getConfigKey = getConfigKey
Vue.prototype.getAge=getAge
Vue.prototype.resetForm = resetForm
Vue.prototype.addDateRange = addDateRange
Vue.prototype.selectDictLabel = selectDictLabel
Vue.prototype.selectDictLabels = selectDictLabels
Vue.prototype.download = download
Vue.prototype.handleTree = handleTree
Vue.prototype.formatMoney = formatMoney
Vue.prototype.parseArr = parseArr
Vue.prototype.parsePost = parsePost

Vue.prototype.parseTime = parseTime
Vue.prototype.transformDateFormat = dateFormat
Vue.prototype.formatDate = formatDate
Vue.prototype.formatTime=formatTime
Vue.prototype.friendlyDate=friendlyDate



import moment from "moment"
Vue.prototype.$moment = moment;

Vue.prototype.msgSuccess = function (msg) {
  this.$message({ showClose: true, message: msg, type: "success" });
}

Vue.prototype.msgError = function (msg) {
  this.$message({ showClose: true, message: msg, type: "error" });
}

Vue.prototype.msgInfo = function (msg) {
  this.$message.info(msg);
}

// 全局组件挂载
Vue.component('Pagination', Pagination)
Vue.component('RightToolbar', RightToolbar)
Vue.component('DictTag', DictTag)

Vue.use(permission)
Vue.use(elementDirective)

/**
 * If you don't want to use mock-server
 * you want to use MockJs for mock api
 * you can execute: mockXHR()
 *
 * Currently MockJs will be used in the production environment,
 * please remove it before going online! ! !
 */

Vue.use(Element, {
  size: Cookies.get('size') || 'medium' // set element-ui default size
})

Vue.config.productionTip = false

new Vue({
  el: '#app',
  router,
  store,
  render: h => h(App)
})
